# django_signalmap/management/commands/signalmap.py

from django.core.management.base import BaseCommand
from django_signalmap.tracker import SIGNAL_MAP

class Command(BaseCommand):
    help = 'Prints a map of Django signals and their connected receivers.'

    def handle(self, *args, **options):
        if not SIGNAL_MAP:
            self.stdout.write("No signal connections have been tracked yet.")
            return
        
        for signal, receivers in SIGNAL_MAP.items():
            self.stdout.write(f"Signal: {signal}")
            for receiver in receivers:
                self.stdout.write(f"  -> Receiver: {receiver}")
            self.stdout.write("")



# setup.py

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django_signalmap",
    version="0.1.1",
    author="Ibrahim Muhaisen",
    author_email="ibrahim.muhaisen.2015@gmail.com",
    description="A Django package to map and visualize signal connections",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/hemaxox/django-signalmap",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Framework :: Django",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires=">=3.6",
)
